@@ -1,10 +1,11 @@
 import asyncio
 import queue
-import requests
 import sys
 import threading
+import time
 
 import aiohttp
+import requests
 
 sys.path.insert(0, '../../frontiersman')
 from frontiersman.gameboard.Board import *
@@ -18,9 +19,10 @@ class client:
     #       self.client_instance.run(board)
 
     def __init__(self):
-        self.enemy_list=[]
+        self.enemy_list = []
+
     async def run(self, url, game_id, player_id, player_name, player_color, screen_num, lobby_obj, host=False):
-        
+
         s = aiohttp.ClientSession()
         board_input = queue.Queue()
         board = Board()
@@ -31,14 +33,15 @@ class client:
         self.client_instance.set_player(Player(player_name, Color, screen_num))
         lobby_obj.client_instance = self.client_instance
         lobby_obj.add_player(self.client_instance.player)
-        print(self.client_instance.player.name)
+        # print(self.client_instance.player.name)
         for e in self.enemy_list:
-            if(e not in lobby_obj.players):
-                print(e.name)
+            if (e not in lobby_obj.players):
+                #print(e.name)
                 lobby_obj.add_player(e)
+
         # Color = input('Choose a color: ')
 
-        print(get_url)
+        # print(get_url)
 
         async def send_message(message):
             await s.post(post_url, data={'msg': message})
@@ -52,7 +55,8 @@ class client:
                     max_value = int(self.client_instance.enemy_list[i].longestRoad)
 
             if (self.client_instance.player.get_longest_road(max_value)):
-                self.client_instance.enemy_list[max_index].visibleVictoryPoints = str(int(self.client_instance.enemy_list[max_index].visibleVictoryPoints) - 2)
+                self.client_instance.enemy_list[max_index].visibleVictoryPoints = str(
+                    int(self.client_instance.enemy_list[max_index].visibleVictoryPoints) - 2)
 
         def get_largest_army():
             max_index = 0
@@ -62,7 +66,8 @@ class client:
                     max_index = i
                     max_value = int(self.client_instance.enemy_list[i].largestArmy)
             if (self.client_instance.player.get_largest_army(max_value)):
-                self.client_instance.enemy_list[max_index].visibleVictoryPoints = str(int(self.client_instance.enemy_list[max_index].visibleVictoryPoints) - 2)
+                self.client_instance.enemy_list[max_index].visibleVictoryPoints = str(
+                    int(self.client_instance.enemy_list[max_index].visibleVictoryPoints) - 2)
 
         def player_hand_down(color):
             for en in self.enemy_list:
@@ -72,25 +77,27 @@ class client:
         while True:
 
             Response = await(await s.get(get_url)).text()
-
-            print('r', Response)
+            if Response=='t':
+                #print('timeout')
+                continue
+            # print('r', Response)
             # if Response == 'host':
             # num_players = self.get_valid_player_input("How many players(including you)? ")
             # add error checking from pakuri here
             #    ClientSocket.send(str.encode(str(num_players) + '\n'))
 
             if Response == "quit" or Response == "game not found":  # add more quit contigency!!!!
-                print(Response)
-                print("a player has disconnected")
+                #print(Response)
+                #print("a player has disconnected")
                 # self.client_instance.quit()
-                lobby_obj.to_menu = True
+                lobby_obj.player_left = True
                 await s.close()
                 return
             elif Response == "leave":
-                print(Response)
-                print("host left")
+                #print(Response)
+                #print("host left")
                 # self.client_instance.quit()
-                lobby_obj.host_left=True
+                lobby_obj.host_left = True
                 await s.close()
                 return
             elif Response == 'set':
@@ -111,7 +118,7 @@ class client:
                 self.client_instance.set_board_updated(True)
                 await send_message(coordinates)
                 await send_message("enemyu," + self.client_instance.player.get_sent_to_enemies())
-
+            
             elif Response == "startroad":
                 self.client_instance.set_board_action("initialroad")
                 coordinates = board_input.get()
@@ -122,10 +129,22 @@ class client:
                 road = self.client_instance.building_locations.claimRoad(int(coordinates.split(',')[0]),
                                                                          int(coordinates.split(',')[1]), Color)
                 self.client_instance.road_list.append(road)
+                self.client_instance.draw_road(road)
                 self.client_instance.player.acquire_road(road)
                 self.client_instance.set_board_updated(True)
                 await send_message(coordinates)
                 await send_message("enemyu," + self.client_instance.player.get_sent_to_enemies())
+            elif Response.split(',')[0] == "turnorder":
+                col=Response.split(',')[1]
+                self.client_instance.turn_player=col
+                if col==Color:
+                    self.client_instance.add_text("<b>Your Turn!</b>")
+                else:
+                    #print([e.name for e in self.client_instance.enemy_list])
+                    for e in self.client_instance.enemy_list:
+                        if e.color==col:
+                            self.client_instance.add_text(e.name+"'s Turn!")
+                self.client_instance.set_board_updated(True)
             elif Response.split(',')[0] == "set":
                 # print("new settlement" + Response.split(',')[1] + Response.split(',')[1])
                 self.client_instance.property_list.append(
@@ -136,10 +155,11 @@ class client:
             elif Response.split(',')[0] == "road":
                 # print("new road")
                 # print("new settlement" + Response.split(',')[1] + Response.split(',')[1])
-                self.client_instance.road_list.append(
-                    self.client_instance.building_locations.claimRoad(int(Response.split(',')[1]),
-                                                                      int(Response.split(',')[2]),
-                                                                      Response.split(',')[3]))
+                road = self.client_instance.building_locations.claimRoad(int(Response.split(',')[1]),
+                                                                         int(Response.split(',')[2]),
+                                                                         Response.split(',')[3])
+                self.client_instance.road_list.append(road)
+                self.client_instance.draw_road(road)
                 self.client_instance.set_board_updated(True)
 
             elif Response.split(',')[0] == "city":
@@ -184,14 +204,15 @@ class client:
                 # board_input.task_done()
             elif Response == "steal":
                 stolen_card = self.client_instance.stolen_card()
+                self.client_instance.add_text("The Robber stole a "+stolen_card+ " from you!")
                 await send_message('stolen,' + stolen_card)
                 await send_message("enemyu," + self.client_instance.player.get_sent_to_enemies())
             elif Response.split(',')[0] == "dice":
                 roll = [int(x) for x in Response.split(',')[1:]]
                 if sum(roll) == 7:
-                    self.client_instance.display_dice(roll)
+                    # self.client_instance.display_dice(roll)
                     continue
-                self.client_instance.display_dice(roll)
+                # self.client_instance.display_dice(roll)
                 self.client_instance.process_dice(sum(roll))
                 message = board_input.get()
                 if message == "quit":
@@ -199,11 +220,22 @@ class client:
                 board_input.task_done()
                 await send_message(message)
                 await send_message("enemyu," + self.client_instance.player.get_sent_to_enemies())
+            elif Response.split(',')[0] == "diceroll":
+                roll = [int(x) for x in Response.split(',')[1:]]
+                self.client_instance.is_rolling = True
+                time.sleep(.5)
+                self.client_instance.is_rolling = False
+                if sum(roll) in [8,11]:
+                    self.client_instance.add_text('An '+ str(sum(roll)) + ' was rolled.')
+                else:
+                    self.client_instance.add_text('A '+ str(sum(roll)) + ' was rolled.')
+                self.client_instance.display_dice(roll)
+                # await send_message('success')
             elif Response.split('|')[0] == "tradeoffer":
                 offer = [int(i) for i in Response.split('|')[2].split(',')]
                 cost = [int(i) for i in Response.split('|')[3].split(',')]
-                print(offer)
-                print(cost)
+                # print(offer)
+                # print(cost)
                 self.client_instance.trade_offer = offer
                 self.client_instance.trade_cost = cost
                 self.client_instance.set_board_action('tradeoffer', 'display')
@@ -222,32 +254,36 @@ class client:
                     if message == "quit":
                         continue
                     board_input.task_done()
-                    print(message)
+                    # print(message)
                     self.client_instance.pay_cards(self.client_instance.card_list_to_arr(message.split(',')))
                     message2 = board_input.get()
-                    print(message2)
+                    # print(message2)
                     if message2 == "quit":
                         continue
                     self.client_instance.set_board_updated(True)
                     await send_message(
                         Color + '|' + message2 + '|' + "enemyu," + self.client_instance.player.get_sent_to_enemies())
             elif Response == "turn" or Response == "robber":
+                self.client_instance.turn_ended = False
+                #self.client_instance.add_text("<b>Your Turn!</b>")
                 self.client_instance.player.development_card_played = False
                 self.client_instance.turn_start = True
                 if Response == "robber":
                     self.client_instance.set_board_action("robber", 'turn')
                 else:
                     self.client_instance.set_board_action("turn")
+
                 while True:
                     message = board_input.get()
                     if message == "quit":
-                        lobby_obj.to_menu = True
+                        lobby_obj.player_left = True
                         await s.close()
                         return
                     elif message.split(',')[0] == "road":
                         road = self.client_instance.building_locations.claimRoad(int(message.split(',')[1]),
                                                                                  int(message.split(',')[2]), Color)
                         self.client_instance.road_list.append(road)
+                        self.client_instance.draw_road(road)
                         self.client_instance.player.acquire_road(road)
                         get_longest_road()
                         self.client_instance.set_board_updated(True)
@@ -258,7 +294,8 @@ class client:
                         await send_message(message + ',' + Color)
                         await send_message("enemyu," + self.client_instance.player.get_sent_to_enemies())
                     elif (message.split(',')[0] == "robber"):
-                        self.client_instance.game_board.set_robber((int(message.split(',')[1]), int(message.split(',')[2])))
+                        self.client_instance.game_board.set_robber(
+                            (int(message.split(',')[1]), int(message.split(',')[2])))
                         # self.client_instance.player.get_largest_army(max([int(en.largestArmy) for en in self.client_instance.enemy_list], default=0))
                         get_largest_army()
                         self.client_instance.set_board_action('thieftarget', 'turn')
@@ -268,16 +305,17 @@ class client:
                         self.client_instance.set_board_action('awaitingtrade')
                         await send_message(message)
                         Response2 = await(await s.get(get_url)).text()
+                        while Response2 == 't':
+                            Response2 = await(await s.get(get_url)).text()
                         if Response2 == "quit" or Response2 == "game not found":  # add more quit contigency!!!!
-                            print("a player has disconnected")
+                            #print("a player has disconnected")
                             # self.client_instance.quit()
-                            await s.close()
-                            lobby_obj.to_menu = True
+                            lobby_obj.player_left = True
                             await s.close()
                             return
                         ens = Response2.split(',')
                         if len(ens) == 1:
-                            print('trade was denied')
+                            self.client_instance.add_text("Trade was Denied")
                             self.client_instance.set_board_action('turn', 'turn')
                         else:
                             ens.pop(0)
@@ -289,7 +327,7 @@ class client:
                             self.client_instance.set_board_action('tradepartner', 'turn')
                             m2 = board_input.get()
                             if m2 == "quit":
-                                lobby_obj.to_menu = True
+                                lobby_obj.player_left = True
                                 await s.close()
                                 return
                             board_input.task_done()
@@ -300,17 +338,19 @@ class client:
                                 self.client_instance.trade_cards_with_player(trade, get)
                                 await send_message("enemyu," + self.client_instance.player.get_sent_to_enemies())
                                 Response2 = await(await s.get(get_url)).text()
+                                while Response2 == 't':
+                                    Response2 = await(await s.get(get_url)).text()
                                 if Response == "quit" or Response == "game not found":  # add more quit contigency!!!!
-                                    print("a player has disconnected")
+                                    #print("a player has disconnected")
                                     # self.client_instance.quit()
-                                    lobby_obj.to_menu = True
+                                    lobby_obj.player_left = True
                                     await s.close()
                                     return
                                 arr = Response2.split(',')[1:]
                                 for en in self.client_instance.enemy_list:
                                     if en.color == arr[1]:
                                         en.update_enemy(arr)
-                                print(m2)
+                                # print(m2)
                             else:
                                 await send_message(m2)
                             # print(ens2)
@@ -318,14 +358,16 @@ class client:
                         await send_message(message)
                         card = await(await s.get(get_url)).text()
                         if card == "quit" or card == "game not found":  # add more quit contigency!!!!
-                            print("a player has disconnected")
+                            #print("a player has disconnected")
                             # self.client_instance.quit()
-                            lobby_obj.to_menu = True
+                            lobby_obj.player_left = True
                             await s.close()
                             return
                         if card.split(',')[1] == "none":
-                            print("no cards to steal")
+                            pass
+                            #print("no cards to steal")
                         else:
+                            self.client_instance.add_text("You stole a "+card.split(',')[1])
                             self.client_instance.steal_card(card.split(',')[1])
                             player_hand_down(message.split(',')[1])
                             self.client_instance.set_board_action('turn')
@@ -347,7 +389,7 @@ class client:
                         board_input.task_done()
                         await send_message(message + ',' + Color)
                         await send_message("enemyu," + self.client_instance.player.get_sent_to_enemies())
-                    elif message == "dev":
+                    elif message == "dev" and Actions.buy_development_check(self.client_instance.player):
                         await send_message(message)
                         card = await(await s.get(get_url)).text()
                         # print(card)
@@ -372,10 +414,10 @@ class client:
                         await send_message(message)
                         await send_message("enemyu," + self.client_instance.player.get_sent_to_enemies())
                     elif message == "end":
-                        print("end")
+                        # print("end")
                         if (
                                 self.client_instance.player.victoryPoints + self.client_instance.player.hiddenVictoryPoints >= 10):
-                            await send_message('winner,' + self.client_instance.player.name)
+                            await send_message('winner,' + self.client_instance.player.get_sent_to_enemies())
                             # ClientSocket.send(str.encode('winner,' + self.client_instance.player.name + '\n'))
                         else:
                             await send_message(message)
@@ -391,13 +433,14 @@ class client:
                             self.client_instance.set_board_action("roadfree", 'turn')
                             message = board_input.get()
                             if message == "quit":
-                                lobby_obj.to_menu = True
+                                lobby_obj.player_left = True
                                 await s.close()
                                 return
                             board_input.task_done()
                             road = self.client_instance.building_locations.claimRoad(int(message.split(',')[1]),
                                                                                      int(message.split(',')[2]), Color)
                             self.client_instance.road_list.append(road)
+                            self.client_instance.draw_road(road)
                             self.client_instance.player.acquire_road(road)
                             get_longest_road()
                             self.client_instance.set_board_updated(True)
@@ -407,13 +450,14 @@ class client:
                             self.client_instance.set_board_action("roadfree", 'turn')
                             message = board_input.get()
                             if message == "quit":
-                                lobby_obj.to_menu = True
+                                lobby_obj.player_left = True
                                 await s.close()
                                 return
                             board_input.task_done()
                             road = self.client_instance.building_locations.claimRoad(int(message.split(',')[1]),
                                                                                      int(message.split(',')[2]), Color)
                             self.client_instance.road_list.append(road)
+                            self.client_instance.draw_road(road)
                             self.client_instance.player.acquire_road(road)
                             get_longest_road()
                             self.client_instance.set_board_updated(True)
@@ -430,22 +474,22 @@ class client:
                 self.client_instance.set_board_updated(True)
             elif Response == "notturn":
                 self.client_instance.set_board_action("display", 'display')
-            #elif Response.split(',')[0] == "enemy":
-                #self.enemy_list.append(EnemyPlayer(Response.split(',')[1], Response.split(',')[2]))
-                #print(Response.split(',')[1], "(" + Response.split(',')[2] + ")", "has joined")
+            # elif Response.split(',')[0] == "enemy":
+            # self.enemy_list.append(EnemyPlayer(Response.split(',')[1], Response.split(',')[2]))
+            # print(Response.split(',')[1], "(" + Response.split(',')[2] + ")", "has joined")
             elif Response.split(',')[0] == "enemy":
-                e=EnemyPlayer(Response.split(',')[1], Response.split(',')[2])
-                if(e not in lobby_obj.players):
-                    print(e.name)
+                e = EnemyPlayer(Response.split(',')[1], Response.split(',')[2])
+                if (e not in lobby_obj.players):
+                    # print(e.name)
                     lobby_obj.add_player(e)
-                if(e not in self.enemy_list):
+                if (e not in self.enemy_list):
                     self.enemy_list.append(e)
             elif Response.split(',')[0] == "enemyleave":
                 for e in self.enemy_list:
-                    if e.color==Response.split(',')[1]:
+                    if e.color == Response.split(',')[1]:
                         lobby_obj.remove_player(e)
                         self.enemy_list.remove(e)
-                        print(self.enemy_list)
+                        # print(self.enemy_list)
             elif Response.split(',')[0] == "enemyu":
                 arr = Response.split(',')[1:]
                 for en in self.client_instance.enemy_list:
@@ -454,9 +498,15 @@ class client:
                         self.client_instance.player.lose_longest_road(int(en.longestRoad))
                         self.client_instance.player.lost_largest_army(int(en.largestArmy))
             elif Response.split(',')[0] == "winner":
-                self.client_instance.running = False  # add a victory screen also need to send who won
-                break
+                if (Response.split(',')[2] == self.client_instance.player.color):
+                    lobby_obj.winner = 'You'
+                else:
+                    lobby_obj.winner = Response.split(',')[1]
 
+                self.client_instance.running = False  # add a victory screen also need to send who won
+                lobby_obj.to_menu = True
+                await s.close()
+                return
             elif Response != "":
                 # print(Response.split(',')[0])
                 pass
@@ -473,19 +523,20 @@ class client:
         lobby_obj.to_menu = True
         return
 
+
 def game_thread_run(client, url, game_code, player_code, name, color, screen_num, window, host):
-    
-    asyncio.run(client.run(url,  game_code, player_code, name, color, screen_num, window, host))
-    print('thread is dead , baby, thread is dead')
+    try:
+        asyncio.run(client.run(url, game_code, player_code, name, color, screen_num, window, host))
+    except RuntimeError:
+        pass
 
 
 def main():
-    if os.path.dirname(__file__)!='':
+    if os.path.dirname(__file__) != '':
         os.chdir(os.path.dirname(__file__))
-    #os.chdir(os.path.dirname(__file__))
-    if len(sys.argv)==2 and sys.argv[1]=="remote":
+    # os.chdir(os.path.dirname(__file__))
+    if len(sys.argv) == 2 and sys.argv[1] == "remote":
         url = 'https://frontiersman.herokuapp.com'
-        
     else:
         url = 'http://127.0.0.1:5000'
     s = requests.Session()
@@ -497,7 +548,7 @@ def main():
             r = s.post(url + '/create', data={'name': lobby_obj.name})
             try:
                 name = lobby_obj.name
-                print(r.text)
+                # print(r.text)
                 response = r.text.split(',')
                 game_code = response[0]
                 lobby_obj.set_lobby_code(game_code)
@@ -505,16 +556,22 @@ def main():
                 lobby_obj.player_code = player_code
                 lobby_obj.color = response[2]
                 lobby_obj.screen_num = response[3]
-                threading.Thread(
-                    target=game_thread_run, args=(client(), url, game_code, player_code, name, lobby_obj.color,
-                                                  lobby_obj.screen_num, lobby_obj, lobby_obj.is_host)).start()
+                try:
+                    threading.Thread(
+                        target=game_thread_run, args=(client(), url, game_code, player_code, name, lobby_obj.color,
+                                                      lobby_obj.screen_num, lobby_obj, lobby_obj.is_host)).start()
+                except RuntimeError:
+                    pass
+                    print('thread\'s dead , baby, thread is dead')
+                
             except:
+                #pass
                 print('non-post related error')
         except:
             lobby_obj.create_notification(['Server Creation Failed', 'Can not reach server'], True)
             return False
         finally:
-            #close threads opened during try
+            # close threads opened during try
             pass
         return True
 
@@ -522,26 +579,37 @@ def main():
         host = False
         data = {'name': lobby_obj.name}
         # name=lobby_obj.name
-        r = s.post(url + '/join/' + lobby_obj.lobby_code, data=data)
-        print(url + '/join/' + lobby_obj.lobby_code)
+        try:
+            r = s.post(url + '/join/' + lobby_obj.lobby_code, data=data)
+        except:
+            return 'fail'
+        # print(url + '/join/' + lobby_obj.lobby_code)
         if r.text == "game not found":
-            print("failed to join")  # add popup later
-            return False
+            #print("failed to join")  # add popup later
+            return 'code'
+        elif r.text == 'game already started':
+            return 'running'
         game_code = lobby_obj.lobby_code
-        print(r.text)
-        print(lobby_obj.players)
+        # print(r.text)
+        # print(lobby_obj.players)
         response = r.text.split('|')
         player_code = response[0].split(',')[0]
         lobby_obj.player_code = player_code
         lobby_obj.color = response[0].split(',')[1]
         lobby_obj.screen_num = response[0].split(',')[2]
-        cli=client()
+        cli = client()
         for x in range(1, len(response)):
-            #addplayers
+            # addplayers
             cli.enemy_list.append(EnemyPlayer(response[x].split(',')[0], response[x].split(',')[1]))
-            #print(response[x].split(',')[0], response[x].split(',')[1])
-        threading.Thread(target=game_thread_run, args=(cli, url,game_code,player_code,lobby_obj.name, lobby_obj.color, lobby_obj.screen_num, lobby_obj, lobby_obj.is_host)).start()
-        return True
+            # print(response[x].split(',')[0], response[x].split(',')[1])
+        try:
+            threading.Thread(target=game_thread_run, args=(
+                cli, url, game_code, player_code, lobby_obj.name, lobby_obj.color, lobby_obj.screen_num, lobby_obj,
+                lobby_obj.is_host)).start()
+        except RuntimeError:
+            #pass
+            print('thread\'s dead , baby, thread is dead')
+        return 'success'
 
     def leave_lobby(lobby_obj):
         post_url = url + '/' + lobby_obj.lobby_code + '/' + lobby_obj.player_code + '/post'
@@ -550,65 +618,26 @@ def main():
         lobby_obj.lobby_status = []
 
     def start(lobby_obj):
+        lobby_obj.loading = True
         post_url = url + '/' + lobby_obj.lobby_code + '/' + lobby_obj.player_code + '/post'
         r = s.post(post_url, data={'msg': 'start'})
+        lobby_obj.loading = False
 
     def host_leave_lobby(name):
         r = s.post(url + '/create', data={'name': name})
-        print(r.text)
-        response = r.text.split(',')
-        game_code = response[0]
-        player_code = response[1]
-        color = response[2]
-        screen_num = response[3]
-
-    test = GameLobby((1600, 900), callbacks=[create_game, join_game, leave_lobby, start])
-
-    '''
-    url = 'http://127.0.0.1:5000'
-    name = sys.argv[1]
-    code = sys.argv[2]
-    s = requests.Session()
-    host = False
-    if (code == "create"):
-        host = True
-
-        data = {'name': name}
-        r = s.post(url + '/create', data=data)
-        print(r.text)
-        response = r.text.split(',')
-        game_code = response[0]
-        player_code = response[1]
-        color = response[2]
-        screen_num = response[3]
-        # r = s.get(url+'/get/'+game_code+'/'+player_code)
         # print(r.text)
-
-
-    else:
-        data = {'name': name}
-        r = s.post(url + '/join/' + code, data=data)
-        print(r.text)
-        if (r.text == "game not found"):
-            print("game not found")
-            return
-        # print(sys.argv)
-        game_code = code
-        response = r.text.split('|')
-        player_code = response[0].split(',')[0]
-        color = response[0].split(',')[1]
-        screen_num = response[0].split(',')[2]
-        for x in range(1, len(response)):
-            self.enemy_list.append(EnemyPlayer(response[x].split(',')[0], response[x].split(',')[1]))
-            print(response[x].split(',')[0], response[x].split(',')[1])
-
-    loop = asyncio.get_event_loop()
+        response = r.text.split(',')
+        game_code = response[0]
+        player_code = response[1]
+        color = response[2]
+        screen_num = response[3]
     try:
-        loop.run_until_complete(client().run( url, game_code, player_code, name, color, screen_num, host))
-    except KeyboardInterrupt:
-        pass
-    '''
-
+        test = GameLobby(RESOLUTION, callbacks=[create_game, join_game, leave_lobby, start])
+    except TypeError as a:
+        try:
+            test.to_menu=True
+        except UnboundLocalError:
+            print(a)
 
 if __name__ == "__main__":
     main()
