@@ -19,13 +19,9 @@ class Bank:
         self.totalDevelopment -= 1
 
     def update(self, update_frame):
-        print(update_frame)
-        print(self.brick , self.grain , self.lumber ,self.ore , self.wool)
         self.brick += update_frame[0]
         self.grain += update_frame[1]
         self.lumber += update_frame[2]
         self.ore += update_frame[3]
         self.wool += update_frame[4]
-        print(self.brick , self.grain , self.lumber ,self.ore , self.wool)
         self.totalResources = self.brick + self.grain + self.lumber + self.ore + self.wool
-    
\ No newline at end of file
