@@ -6,6 +6,8 @@ import pygame_gui
 from pygame_gui.core.utility import clipboard_copy
 
 sys.path.insert(0, '../../frontiersman')
+from frontiersman.client.ClientGraphics import ClientGraphics
+from frontiersman.main.DrawHelper import DrawHelper
 from frontiersman.main.PopUp import PopUp
 # sys.path.insert(0, '../../frontiersman')
 from pygame_gui.elements import UITextEntryLine
@@ -30,12 +32,12 @@ class GameLobby:
         pygame.display.update()
 
     def __init__(self, size, host=False, callbacks=None, manager=None):
-        # print(os.getcwd())
         self.name = 'Nick'
         self.code = None
         self.font = None
         self.small_font = None
         self.large_font = None
+        self.smaller_font = None
         self.state = 'menu'  # menu, join, create
         self.prompt_color = (255, 255, 255)
         self.text_color = (0, 0, 0)
@@ -46,6 +48,7 @@ class GameLobby:
         self.init_pygame()
         self.is_host = host
         self.players = []
+        self.loading =False
         # self.is_host = True
         self.notify_window_up = False
         self.notify_windows = []
@@ -60,8 +63,9 @@ class GameLobby:
         self.to_menu = False
         self.run_game = False
         self.host_left = False
+        self.player_left= False
         self.client_instance = None
-
+        self.winner=''
         if manager is None:
             self.manager = pygame_gui.UIManager(size, './themes/menu_theme.json')
         else:
@@ -110,7 +114,6 @@ class GameLobby:
                 self.change_state()
                 self.run_game = False
             elif self.to_menu:
-                print("to menu!")
                 self.lobby_code = ''
                 self.player_code = ''
                 self.name = ''
@@ -120,9 +123,10 @@ class GameLobby:
                 self.lobby_status = []
                 self.state = 'menu'
                 self.change_state()
+                if self.winner!='':
+                    self.create_notification(self.winner+' won!')
                 self.to_menu = False
             elif self.host_left:
-                print("to menu!")
                 self.lobby_code = ''
                 self.player_code = ''
                 self.name = ''
@@ -135,11 +139,22 @@ class GameLobby:
                 if not self.is_host:
                     self.create_notification("Host left, lobby terminated")
                 self.host_left = False
-            
+            elif self.player_left:
+                self.lobby_code = ''
+                self.player_code = ''
+                self.name = ''
+                self.color = ''
+                self.screen_num = ''
+                self.players = []
+                self.lobby_status = []
+                self.state = 'menu'
+                self.change_state()
+                #if not self.is_host:
+                self.create_notification("A player has left the game")
+                self.player_left = False
             if self.state == "game":
                 self.client_instance.update_frame()
-                if not self.client_instance.running:
-                    print('testing bitch')
+                if not self.client_instance.running and self.winner=='':
                     break
             else:
                 try:
@@ -162,7 +177,6 @@ class GameLobby:
                         # break
                     for event in pygame.event.get():
                         # close if X is clicked
-                        # print(event)
                         if event.type == pygame.QUIT:
                             # self.running = False
                             if self.state == 'lobby':
@@ -171,8 +185,8 @@ class GameLobby:
                             self.change_state()
                         if event.type == pygame.KEYDOWN:
                             if event.key == pygame.key.key_code('0'):
-                                print('0')
-                                self.graphics_banner()
+                                #self.graphics_banner()
+                                self.graphics_test()
 
                         self.manager.process_events(event)
                         if event.type == pygame.USEREVENT:
@@ -239,10 +253,15 @@ class GameLobby:
                                             if error:
                                                 self.create_notification(error_strings, True)
                                             else:
-                                                if self.callbacks[1](self):
+                                                res=self.callbacks[1](self)
+                                                if res=='success':
                                                     self.state = 'lobby'
                                                     self.change_state()
-                                                else:
+                                                elif res=='running':
+                                                    self.create_notification("Game Already Started")
+                                                elif res=='code':
+                                                    self.create_notification("Game Not Found")
+                                                elif res=='fail':
                                                     self.create_notification("Didn't connect")
                                         elif event.ui_element == self.button_list[1]:
                                             self.state = 'menu'
@@ -275,7 +294,10 @@ class GameLobby:
                                 animations[1] -= 1
                             else:
                                 self.animations.remove(animations)
+                    if self.window is None:
+                        self.window=pygame.Surface(self.size)
                     self.manager.draw_ui(self.window)
+                    
 
                     pygame.display.update()
                 except AttributeError:
@@ -331,6 +353,7 @@ class GameLobby:
             flag = True
             pass
         if self.state == 'game':
+            self.winner=''
             self.client_instance.run(self.board)
             flag = True
         if self.state == 'quit':
@@ -402,6 +425,10 @@ class GameLobby:
         elif string == 'text':
             return 'text', self.manager, self.text_list_func
 
+    def graphics_test(self):
+        graphics = ClientGraphics.test_info_cards(self.size, self.small_font, self.smaller_font)
+        self.graphics.blit(graphics, (0, 0))
+
     def graphics_banner(self, text='Cool fading banner wooooo'):
         graphics = pygame.Surface(self.size, flags=pygame.SRCALPHA)
 
@@ -410,7 +437,7 @@ class GameLobby:
 
         #font = pygame.font.Font(self.font, 64)
 
-        transparency = 255
+        transparency = 200
         transparent_step = 2
 
         shadow_color = (0, 0, 0, transparency)
@@ -670,123 +697,7 @@ class GameLobby:
         self.font = pygame.font.Font("./data/fonts/impact.ttf", self.size[1] // 12)
         self.large_font = pygame.font.Font("./data/fonts/impact.ttf", self.size[1] // 6)
         self.small_font = pygame.font.Font("./data/fonts/impact.ttf", self.size[1] // 24)
-
-
-class DrawHelper:
-    @staticmethod
-    def x_centered(size, location):
-        return location[0] - size[0] // 2, location[1]
-
-    @staticmethod
-    def y_centered(size, location):
-        return location[0], location[1] - size[1] // 2
-
-    @staticmethod
-    def xy_centered(size, location):
-        return location[0] - size[0] // 2, location[1] - size[1] // 2
-
-    @staticmethod
-    def input_box(screen_size, surface, location, size, color, padding=0, function=None, name=None, radius=10):
-        # tired of copy pasting, function is [string (type of function), ui manager, callback for adding it]
-        h_scale = screen_size[0] // 20
-        v_scale = screen_size[1] // 20
-        size = (size[0] * h_scale - padding, size[1] * v_scale - padding)
-        location = (location[0] * h_scale, location[1] * v_scale)
-        location = DrawHelper.xy_centered(size, location)
-        if function is not None:
-            if function[0] == 'button':
-                function[2](
-                    pygame_gui.elements.UIButton(
-                        relative_rect=pygame.Rect(location, size),
-                        text='', manager=function[1],
-                        object_id='#menu_button_rounded')
-                )
-                DrawHelper.rounded_rectangle(
-                    surface, location, size[0],
-                    size[1], radius, color)
-            if function[0] == 'text':
-                text_entry = UITextEntryLine(
-                    relative_rect=pygame.Rect(location, size),
-                    manager=function[1],
-                    object_id=name)
-                text_entry.set_forbidden_characters([',', '|', '&', '\\', '#'])
-                function[2](text_entry)
-                DrawHelper.rounded_rectangle(
-                    surface, location, size[0],
-                    size[1], radius, (61, 120, 180))
-        else:
-            DrawHelper.rounded_rectangle(
-                surface, location, size[0],
-                size[1], radius, color)
-
-    @staticmethod
-    def big_text(text, screen_size, surface, location, color, font, width=None):
-        text_surface = pygame.font.Font.render(font, text, True, color, None)
-        if width is None:
-            pass
-        else:
-            h_scale = screen_size[0] // 20
-            max_width = width * h_scale - h_scale * 0.5
-            text_surface = pygame.font.Font.render(font, text, True, color, None)
-            if text_surface.get_width() >= max_width:
-                new_ratio = text_surface.get_width() / max_width
-                new_height = int(text_surface.get_height() / new_ratio)
-                new_width = int(text_surface.get_width() / new_ratio)
-                text_surface = pygame.transform.scale(text_surface, (new_width, new_height))
-        position = (int(screen_size[0] // 20 * location[0] - text_surface.get_width() / 2),
-                    int(screen_size[1] // 20 * location[1] - text_surface.get_height() / 2))
-        surface.blit(text_surface, position)
-
-    @staticmethod
-    def left_text(text, screen_size, surface, location, color, font, padding):
-        text = pygame.font.Font.render(font, text, True, color, None)
-        position = (int(screen_size[0] // 20 * location[0] + padding),
-                    int(screen_size[1] // 20 * location[1]) - text.get_height() / 2)
-        surface.blit(text, position)
-
-    @staticmethod
-    def intify(float_tuple):
-        return int(float_tuple[0]), int(float_tuple[1])
-
-    @staticmethod
-    def rounded_rectangle(surface, location, width, height, radius, color):
-        circle_x = [location[0] + radius, location[0] + width - radius - 1]
-        circle_y = [location[1] + radius, location[1] + height - radius - 1]
-
-        circle_centers = [
-            (circle_x[0], circle_y[0]),
-            (circle_x[0], circle_y[1]),
-            (circle_x[1], circle_y[0]),
-            (circle_x[1], circle_y[1])
-        ]
-
-        for points in circle_centers:
-            pygame.gfxdraw.filled_circle(surface, points[0], points[1], radius, color)
-
-        pygame.gfxdraw.box(surface, pygame.Rect(
-            DrawHelper.intify((location[0] + radius, location[1])),
-            DrawHelper.intify((width - radius * 2, height))
-        ), color)
-
-        pygame.gfxdraw.box(surface, pygame.Rect(
-            DrawHelper.intify((location[0], location[1] + radius)),
-            DrawHelper.intify((width, height - radius * 2))
-        ), color)
-
-    @staticmethod
-    def rectangle(surface, location, width, height, color):
-
-        h_scale = surface.get_width() // 20
-        v_scale = surface.get_height() // 20
-
-        location = DrawHelper.intify((h_scale * location[0], v_scale * location[1]))
-        size = DrawHelper.intify((h_scale * width, v_scale * height))
-
-        pygame.gfxdraw.box(surface, pygame.Rect(
-            DrawHelper.intify(location),
-            DrawHelper.intify(size)
-        ), color)
-
+        self.smaller_font = pygame.font.Font("./data/fonts/impact.ttf", self.size[1] // 36)
 
 if __name__ == "__main__":
-    GameLobby((1200, 900))
+    GameLobby((1200, 900))
\ No newline at end of file
